@@ -7,8 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KONTACT_ICONSIDEPANEBASE_H
-#define KONTACT_ICONSIDEPANEBASE_H
+#pragma once
 
 #include "sidepanebase.h"
 
@@ -82,7 +81,7 @@ private Q_SLOTS:
 
 private:
     void setHelpText(QAction *act, const QString &text);
-    SidePaneBase *mSidePane = nullptr;
+    SidePaneBase *const mSidePane;
     MainWindow *mMainWindow = nullptr;
     Model *mModel = nullptr;
 
@@ -120,4 +119,3 @@ private:
 };
 }
 
-#endif
