@@ -15,7 +15,6 @@ using namespace Kontact;
 #include <KAboutData>
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <QComboBox>
 
 #include <QCheckBox>
@@ -29,7 +28,7 @@ KcmKontact::KcmKontact(QWidget *parent, const QVariantList &args)
     , mPluginCombo(new QComboBox(parent))
 {
     auto topLayout = new QVBoxLayout(this);
-    QBoxLayout *pluginStartupLayout = new QHBoxLayout();
+    auto pluginStartupLayout = new QHBoxLayout();
     topLayout->addLayout(pluginStartupLayout);
 
     auto forceStartupPluginCheckBox = new QCheckBox(Prefs::self()->forceStartupPluginItem()->label(), this);
@@ -41,7 +40,7 @@ KcmKontact::KcmKontact(QWidget *parent, const QVariantList &args)
                                      "Select the plugin from this drop down list to be used as the "
                                      "initial plugin each time Kontact is started. Otherwise, Kontact "
                                      "will restore the last active plugin from the previous usage."));
-    connect(mPluginCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, [this]() {
+    connect(mPluginCombo, &QComboBox::currentIndexChanged, this, [this]() {
         Q_EMIT changed(true);
     });
     pluginStartupLayout->addWidget(mPluginCombo);
@@ -62,8 +61,7 @@ KcmKontact::KcmKontact(QWidget *parent, const QVariantList &args)
 void KcmKontact::load()
 {
     const KConfigGroup grp(Prefs::self()->config(), "Plugins");
-
-    const QVector<KPluginMetaData> pluginMetaDatas = KPluginLoader::findPlugins(QStringLiteral("kontact5"), [](const KPluginMetaData &data) {
+    const QVector<KPluginMetaData> pluginMetaDatas = KPluginMetaData::findPlugins(QStringLiteral("kontact5"), [](const KPluginMetaData &data) {
         return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
     });
 
@@ -85,7 +83,7 @@ void KcmKontact::load()
 
         // skip disabled plugins
         const QString pluginName = plugin.pluginId();
-        if (!grp.readEntry(pluginName + QStringLiteral("Enabled"), false)) {
+        if (!grp.readEntry(pluginName + QStringLiteral("Enabled"), true)) {
             const QStandardItemModel *qsm = qobject_cast<QStandardItemModel *>(mPluginCombo->model());
             if (qsm) {
                 qsm->item(mPluginCombo->count() - 1, 0)->setEnabled(false);
