@@ -6,11 +6,11 @@
 
 #pragma once
 
-#include <ksettings/Dialog>
+#include "ksettingsdialog/kontactsettingsdialog.h"
 
 namespace Kontact
 {
-class KontactConfigureDialog : public KSettings::Dialog
+class KontactConfigureDialog : public KontactSettingsDialog
 {
     Q_OBJECT
 
