@@ -10,9 +10,11 @@
 */
 
 #include "kontactkcmultidialog.h"
-#include "kcmoduleproxy.h"
+#include "kontact_debug.h"
 #include "kontactkcmultidialog_p.h"
 
+#include <KCModuleProxy>
+#include <KIO/ApplicationLauncherJob>
 #include <QApplication>
 #include <QDesktopServices>
 #include <QDesktopWidget>
@@ -25,6 +27,7 @@
 #include <QStyle>
 #include <QUrl>
 
+#include <KDialogJobUiDelegate>
 #include <KGuiItem>
 #include <KIconUtils>
 #include <KLocalizedString>
@@ -368,7 +371,14 @@ void KontactKCMultiDialog::slotHelpClicked()
     const QUrl docUrl = QUrl(QStringLiteral("help:/")).resolved(QUrl(docPath)); // same code as in KHelpClient::invokeHelp
     const QString docUrlScheme = docUrl.scheme();
     if (docUrlScheme == QLatin1String("help") || docUrlScheme == QLatin1String("man") || docUrlScheme == QLatin1String("info")) {
-        QProcess::startDetached(QStringLiteral("khelpcenter"), QStringList() << docUrl.toString());
+        const KService::Ptr service = KService::serviceByDesktopName(QStringLiteral("khelpcenter"));
+        if (service) {
+            auto job = new KIO::ApplicationLauncherJob(service);
+            job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+            job->start();
+        } else {
+            qCWarning(KONTACT_LOG) << "Could not find khelpcenter in PATH.";
+        }
     } else {
         QDesktopServices::openUrl(docUrl);
     }
