@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,7 @@
 IntroductionWebEngineView::IntroductionWebEngineView(QWidget *parent)
     : QWebEngineView(parent)
 {
-    auto *pageEngine = new IntroductionWebEnginePage(this);
+    auto pageEngine = new IntroductionWebEnginePage(this);
     setPage(pageEngine);
 
     setFocusPolicy(Qt::WheelFocus);
@@ -23,5 +23,5 @@ IntroductionWebEngineView::~IntroductionWebEngineView()
 
 void IntroductionWebEngineView::contextMenuEvent(QContextMenuEvent *)
 {
-    //Don't define contextmenu
+    // Don't define contextmenu
 }
